@@ -97,41 +97,41 @@ class Exceptions:
 
 class CodeBuildClient:
     """
-    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client)
+    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client)
     """
 
     exceptions: Exceptions
 
     def batch_delete_builds(self, ids: List[str]) -> BatchDeleteBuildsOutputTypeDef:
         """
-        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
+        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
         """
 
     def batch_get_builds(self, ids: List[str]) -> BatchGetBuildsOutputTypeDef:
         """
-        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
+        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
         """
 
     def batch_get_projects(self, names: List[str]) -> BatchGetProjectsOutputTypeDef:
         """
-        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
+        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
         """
 
     def batch_get_report_groups(
         self, reportGroupArns: List[str]
     ) -> BatchGetReportGroupsOutputTypeDef:
         """
-        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
+        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
         """
 
     def batch_get_reports(self, reportArns: List[str]) -> BatchGetReportsOutputTypeDef:
         """
-        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
+        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
         """
 
     def create_project(
@@ -157,7 +157,7 @@ class CodeBuildClient:
         fileSystemLocations: List["ProjectFileSystemLocationTypeDef"] = None,
     ) -> CreateProjectOutputTypeDef:
         """
-        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.create_project)
+        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.create_project)
         """
 
     def create_report_group(
@@ -168,7 +168,7 @@ class CodeBuildClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateReportGroupOutputTypeDef:
         """
-        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
+        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
         """
 
     def create_webhook(
@@ -178,37 +178,37 @@ class CodeBuildClient:
         filterGroups: List[List["WebhookFilterTypeDef"]] = None,
     ) -> CreateWebhookOutputTypeDef:
         """
-        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
+        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
         """
 
     def delete_project(self, name: str) -> Dict[str, Any]:
         """
-        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.delete_project)
+        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.delete_project)
         """
 
     def delete_report(self, arn: str) -> Dict[str, Any]:
         """
-        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.delete_report)
+        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.delete_report)
         """
 
     def delete_report_group(self, arn: str) -> Dict[str, Any]:
         """
-        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
+        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
         """
 
     def delete_resource_policy(self, resourceArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
         """
 
     def delete_source_credentials(self, arn: str) -> DeleteSourceCredentialsOutputTypeDef:
         """
-        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
+        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
         """
 
     def delete_webhook(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
+        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
         """
 
     def describe_test_cases(
@@ -219,7 +219,7 @@ class CodeBuildClient:
         filter: TestCaseFilterTypeDef = None,
     ) -> DescribeTestCasesOutputTypeDef:
         """
-        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
+        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
         """
 
     def generate_presigned_url(
@@ -230,12 +230,12 @@ class CodeBuildClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
         """
 
     def get_resource_policy(self, resourceArn: str) -> GetResourcePolicyOutputTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
         """
 
     def import_source_credentials(
@@ -247,19 +247,19 @@ class CodeBuildClient:
         shouldOverwrite: bool = None,
     ) -> ImportSourceCredentialsOutputTypeDef:
         """
-        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
+        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
         """
 
     def invalidate_project_cache(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
+        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
         """
 
     def list_builds(
         self, sortOrder: Literal["ASCENDING", "DESCENDING"] = None, nextToken: str = None
     ) -> ListBuildsOutputTypeDef:
         """
-        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_builds)
+        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_builds)
         """
 
     def list_builds_for_project(
@@ -269,12 +269,12 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListBuildsForProjectOutputTypeDef:
         """
-        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
+        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
         """
 
     def list_curated_environment_images(self) -> ListCuratedEnvironmentImagesOutputTypeDef:
         """
-        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
+        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
         """
 
     def list_projects(
@@ -284,7 +284,7 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListProjectsOutputTypeDef:
         """
-        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_projects)
+        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_projects)
         """
 
     def list_report_groups(
@@ -295,7 +295,7 @@ class CodeBuildClient:
         maxResults: int = None,
     ) -> ListReportGroupsOutputTypeDef:
         """
-        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
+        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
         """
 
     def list_reports(
@@ -306,7 +306,7 @@ class CodeBuildClient:
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsOutputTypeDef:
         """
-        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_reports)
+        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_reports)
         """
 
     def list_reports_for_report_group(
@@ -318,7 +318,7 @@ class CodeBuildClient:
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsForReportGroupOutputTypeDef:
         """
-        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
+        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
         """
 
     def list_shared_projects(
@@ -329,7 +329,7 @@ class CodeBuildClient:
         nextToken: str = None,
     ) -> ListSharedProjectsOutputTypeDef:
         """
-        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
+        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
         """
 
     def list_shared_report_groups(
@@ -340,17 +340,17 @@ class CodeBuildClient:
         maxResults: int = None,
     ) -> ListSharedReportGroupsOutputTypeDef:
         """
-        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
+        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
         """
 
     def list_source_credentials(self) -> ListSourceCredentialsOutputTypeDef:
         """
-        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
+        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
         """
 
     def put_resource_policy(self, policy: str, resourceArn: str) -> PutResourcePolicyOutputTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
         """
 
     def start_build(
@@ -380,7 +380,11 @@ class CodeBuildClient:
         reportBuildStatusOverride: bool = None,
         buildStatusConfigOverride: "BuildStatusConfigTypeDef" = None,
         environmentTypeOverride: Literal[
-            "WINDOWS_CONTAINER", "LINUX_CONTAINER", "LINUX_GPU_CONTAINER", "ARM_CONTAINER"
+            "WINDOWS_CONTAINER",
+            "LINUX_CONTAINER",
+            "LINUX_GPU_CONTAINER",
+            "ARM_CONTAINER",
+            "WINDOWS_SERVER_2019_CONTAINER",
         ] = None,
         imageOverride: str = None,
         computeTypeOverride: Literal[
@@ -400,14 +404,15 @@ class CodeBuildClient:
         logsConfigOverride: "LogsConfigTypeDef" = None,
         registryCredentialOverride: "RegistryCredentialTypeDef" = None,
         imagePullCredentialsTypeOverride: Literal["CODEBUILD", "SERVICE_ROLE"] = None,
+        debugSessionEnabled: bool = None,
     ) -> StartBuildOutputTypeDef:
         """
-        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.start_build)
+        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.start_build)
         """
 
     def stop_build(self, id: str) -> StopBuildOutputTypeDef:
         """
-        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.stop_build)
+        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.stop_build)
         """
 
     def update_project(
@@ -433,7 +438,7 @@ class CodeBuildClient:
         fileSystemLocations: List["ProjectFileSystemLocationTypeDef"] = None,
     ) -> UpdateProjectOutputTypeDef:
         """
-        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.update_project)
+        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.update_project)
         """
 
     def update_report_group(
@@ -443,7 +448,7 @@ class CodeBuildClient:
         tags: List["TagTypeDef"] = None,
     ) -> UpdateReportGroupOutputTypeDef:
         """
-        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
+        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
         """
 
     def update_webhook(
@@ -454,7 +459,7 @@ class CodeBuildClient:
         filterGroups: List[List["WebhookFilterTypeDef"]] = None,
     ) -> UpdateWebhookOutputTypeDef:
         """
-        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
+        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
         """
 
     @overload
@@ -462,13 +467,13 @@ class CodeBuildClient:
         self, operation_name: Literal["describe_test_cases"]
     ) -> DescribeTestCasesPaginator:
         """
-        [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
+        [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_builds"]) -> ListBuildsPaginator:
         """
-        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
         """
 
     @overload
@@ -476,13 +481,13 @@ class CodeBuildClient:
         self, operation_name: Literal["list_builds_for_project"]
     ) -> ListBuildsForProjectPaginator:
         """
-        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
         """
 
     @overload
@@ -490,13 +495,13 @@ class CodeBuildClient:
         self, operation_name: Literal["list_report_groups"]
     ) -> ListReportGroupsPaginator:
         """
-        [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
+        [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_reports"]) -> ListReportsPaginator:
         """
-        [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
+        [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
         """
 
     @overload
@@ -504,7 +509,7 @@ class CodeBuildClient:
         self, operation_name: Literal["list_reports_for_report_group"]
     ) -> ListReportsForReportGroupPaginator:
         """
-        [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
+        [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
         """
 
     @overload
@@ -512,7 +517,7 @@ class CodeBuildClient:
         self, operation_name: Literal["list_shared_projects"]
     ) -> ListSharedProjectsPaginator:
         """
-        [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
+        [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
         """
 
     @overload
@@ -520,7 +525,7 @@ class CodeBuildClient:
         self, operation_name: Literal["list_shared_report_groups"]
     ) -> ListSharedReportGroupsPaginator:
         """
-        [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.22/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
+        [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.25/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
         """
 
     def get_paginator(self, operation_name: str) -> Boto3Paginator:
